==> react-native-segmented-progress-1.0.1.tgz: package/src/SegmentedProgress.js <==
var React = require('react');
import PropTypes from 'prop-types';

import {StyleSheet, View, TouchableHighlight} from 'react-native';

class SegmentedProgress extends React.Component {
	
	constructor(props) {
		super(props);
		
		this.state = {style: this.getStyle()}
	}
	
	componentWillUpdate(nextProps, nextState) {
		// Check if the props updated, if yes change the style
		const propsToCheck = ['tintColor', 'segmentMargin'];
		for (var i = 0, len = propsToCheck.length; i < len; i++) {
		  	var object = propsToCheck[i];
			if (nextProps[object] != this.props[object]) {
				this.setState({style: this.getStyle()});
				break
			}
		}
	}
	
	getStyle() {
		return StyleSheet.create({
			container: {
				flexDirection: 'row'
			},
			step: {
				flex: 1,
				margin: this.props.segmentMargin,
				backgroundColor: this.props.tintColor
			}
		})
	}
	
	render () {
		var stepComponents = [];
		for(var i = 0; i < props.numberOfSteps; i++){
			var opacity = 0.5;
			if (i == props.activeStep) {
				opacity = 1.0;
			} else if (i < props.activeStep) {
				opacity = 0.8;
			}
			stepComponents.push(<View key={i} style={[styles.step, {opacity: opacity}]} />)
		}
		return <View style={[styles.container, props.style]}>
			{stepComponents}
		</View>
	}
}

SegmentedProgress.defaultProps = {
	tintColor: 'white',
	segmentMargin: 4
};

SegmentedProgress.propTypes = {
    numberOfSteps: PropTypes.number.isRequired,
    activeStep: PropTypes.number.isRequired,
	tintColor: PropTypes.string,
	segmentMargin: PropTypes.number
};

export default SegmentedProgress;

==> react-native-segmented-progress-1.0.2.tgz: package/src/SegmentedProgress.js <==
var React = require('react');
import PropTypes from 'prop-types';

import {StyleSheet, View, TouchableHighlight} from 'react-native';

class SegmentedProgress extends React.Component {
	
	constructor(props) {
		super(props);
		
		this.state = {style: this.getStyle()}
	}
	
	componentWillUpdate(nextProps, nextState) {
		// Check if the props updated, if yes change the style
		const propsToCheck = ['tintColor', 'segmentMargin'];
		for (var i = 0, len = propsToCheck.length; i < len; i++) {
		  	var object = propsToCheck[i];
			if (nextProps[object] != this.props[object]) {
				this.setState({style: this.getStyle()});
				break
			}
		}
	}
	
	getStyle() {
		return StyleSheet.create({
			container: {
				flexDirection: 'row'
			},
			step: {
				flex: 1,
				margin: this.props.segmentMargin,
				backgroundColor: this.props.tintColor
			}
		})
	}
	
	render () {
		var stepComponents = [];
		for(var i = 0; i < this.props.numberOfSteps; i++){
			var opacity = 0.5;
			if (i == this.props.activeStep) {
				opacity = 1.0;
			} else if (i < this.props.activeStep) {
				opacity = 0.8;
			}
			stepComponents.push(<View key={i} style={[styles.step, {opacity: opacity}]} />)
		}
		return <View style={[styles.container, this.props.style]}>
			{stepComponents}
		</View>
	}
}

SegmentedProgress.defaultProps = {
	tintColor: 'white',
	segmentMargin: 4
};

SegmentedProgress.propTypes = {
    numberOfSteps: PropTypes.number.isRequired,
    activeStep: PropTypes.number.isRequired,
	tintColor: PropTypes.string,
	segmentMargin: PropTypes.number
};

export default SegmentedProgress;
